Learn R Programming

spikeslab (version 1.0.2)

diabetesI: Diabetes Data with Interactions

Description

The data consists of 442 patients in which the response of interest is a quantitative measure of disease progression. The data includes 10 baseline measurements for each patient, in addition to 45 interactions and 9 quadratic terms, for a total of 64 variables for each patient. The outcome is Y.

Arguments

source

Efron B., Hastie T., Johnstone. I and Tibshirani R. (2004). Least angle regression (with discussion). Ann. Statist., 32:407-499.

Examples

Run this code
data(diabetesI, package = "spikeslab")

Run the code above in your browser using DataLab