Usage
cv.spikeslab(x = NULL, y = NULL, K = 10, plot.it = TRUE,
n.iter1 = 500, n.iter2 = 500, mse = TRUE,
bigp.smalln = FALSE, bigp.smalln.factor = 1, screen = (bigp.smalln),
r.effects = NULL, max.var = 500, center = TRUE, intercept = TRUE,
fast = TRUE, beta.blocks = 5, verbose = TRUE, ntree = 300,
seed = NULL, ...)Arguments
plot.it
If TRUE, plots the mean prediction error and its standard error.
n.iter1
Number of burn-in Gibbs sampled values (i.e., discarded values).
n.iter2
Number of Gibbs sampled values, following burn-in.
mse
If TRUE, an external estimate for the overall variance is calculated.
bigp.smalln
Use if p >> n.
bigp.smalln.factor
Top n times this value of variables
to be kept in the filtering step (used when p >> n).
screen
If TRUE, variables are first pre-filtered.
r.effects
List used for grouping variables (see details below).
max.var
Maximum number of variables allowed in the final model.
center
If TRUE, variables are centered by their
means. Default is TRUE and should only be adjusted in extreme examples.
intercept
If TRUE, an intercept is included in the model,
otherwise no intercept is included. Default is TRUE.
fast
If TRUE, use blocked Gibbs sampling to accelerate the algorithm.
beta.blocks
Update beta using this number of blocks (fast
must be TRUE).
verbose
If TRUE, verbose output is sent to the terminal.
ntree
Number of trees used by random forests (applies only when mse is TRUE).
seed
Seed for random number generator. Must be a negative
integer.
...
Further arguments passed to or from other methods.